#ifndef NT2_INCLUDE_FUNCTIONS_BINOMIAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_BINOMIAL_HPP_INCLUDED

#include <nt2/gallery/include/functions/binomial.hpp>

#endif
